@@ -211,7 +211,7 @@ append_extension_key_usage (GcrRenderer *renderer,
 		if (key_usage & usage_descriptions[i].usage) {
 			if (text->len > 0)
 				g_string_append_unichar (text, GCR_DISPLAY_VIEW_LINE_BREAK);
-			g_string_append (text, gettext (usage_descriptions[i].description));
+			g_string_append (text, _(usage_descriptions[i].description));
 		}
 	}
 
@@ -273,13 +273,6 @@ append_extension_hex (GcrRenderer *renderer,
 	return TRUE;
 }
 
-static gboolean
-on_delete_unref_dialog (GtkWidget *widget, GdkEvent *event, gpointer data)
-{
-	g_object_unref (widget);
-	return FALSE;
-}
-
 static void
 on_export_completed (GObject *source, GAsyncResult *result, gpointer user_data)
 {
@@ -297,7 +290,8 @@ on_export_completed (GObject *source, GAsyncResult *result, gpointer user_data)
 				  error->message);
 			gtk_widget_show (dialog);
 			g_signal_connect (dialog, "delete-event",
-					  G_CALLBACK (on_delete_unref_dialog), NULL);
+					  G_CALLBACK (gtk_widget_destroy), dialog);
+			g_signal_connect_swapped(dialog, "response", G_CALLBACK (gtk_widget_destroy), dialog);
 		}
 	}
 
@@ -621,7 +615,7 @@ gcr_certificate_renderer_populate_popup (GcrRenderer *self, GcrViewer *viewer,
 	gtk_widget_show (item);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 
-	item = gtk_menu_item_new_with_label ("Export Certificate...");
+	item = gtk_menu_item_new_with_label (_("Export Certificate..."));
 	gtk_widget_show (item);
 	g_signal_connect_data (item, "activate", G_CALLBACK (on_certificate_export),
 	                       g_object_ref (self), (GClosureNotify)g_object_unref, 0);
